.. _database:

Database
========

After fitting a large suite of strong lens data, **PyAutoLens**'s database tools allow you to load the results and
manipulate, interpret and visualize them using a Python script or Jupyter notebook.

The readthedocs overview for the **database** is not written yet, so checkout
`the database tutorials on the autolens workspace <https://github.com/Jammy2211/autolens_workspace/tree/master/notebooks/database>`_
for a full description.